Description Usage Arguments Value Examples
View source: R/utility_functions.R
Random Letter Generator
1 | randomLetter(n, letter_probs = rep(1/26, 26), wreplacement = FALSE)
|
n |
the number of random letters you want to select |
letter_probs |
a vector of probabilities for each of the 26 letters (optional), default is 1/26 |
wreplacement |
if you want multiple letters, logical TRUE/FALSE for sampling with replacement (optional), FALSE default |
a random letter based on probabilities
1 2 | randomLetter(1) # select 1 random letter
randomLetter(2) # select 2 random letters
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.